@@ -4,6 +4,10 @@ import os
 import sys
 import subprocess
 import time
+from multiprocessing.connection import Client
+
+PROCESS_COMMUNICATION_PASSWORD = b'9oB!jZabGhaE9lCNxj'
+PROCESS_COMMUNICATION_PORT = 6984
 
 curDir = os.path.dirname(os.path.realpath(__file__))
 resourcePath = os.path.join(curDir, '../resources/')
@@ -234,14 +238,19 @@ def exportAvatar():
 
 def exportFinish():
     task_params = loadJson('nowyou_task_params.json')
-    BwApi.WndMessageBox("have tasks", BwApi.BW_API_MB_OK)
     avatar_params = loadJson('export_schema.json')
-    BwApi.WndMessageBox("have avatar", BwApi.BW_API_MB_OK)
-    avatar_params['path'] = os.path.join(task_params['work_path'], 'avatar.fbx')
-    BwApi.WndMessageBox(json.dumps(avatar_params), BwApi.BW_API_MB_OK)
+
+    output_name = 'avatar.fbx'
+    avatar_params['path'] = os.path.join(task_params['work_path'], output_name)
 
     garmentId = BwApi.GarmentId()
-    BwApi.RenderExport3DObject(garmentId, json.dumps())
+    BwApi.RenderExport3DObject(garmentId, json.dumps(avatar_params))
+
+    # send confirm message
+    address = ('localhost', PROCESS_COMMUNICATION_PORT)
+    conn = Client(address, authkey=PROCESS_COMMUNICATION_PASSWORD)
+    conn.send(output_name)
+    conn.close()
 
 
 # Main
